@@ -1,9 +1,6 @@
 package Compress::LZW;
-{
-  $Compress::LZW::VERSION = '0.03';
-}
 # ABSTRACT: Pure-Perl implementation of scaling LZW
-
+$Compress::LZW::VERSION = '0.04';
 
 use strictures;
 
@@ -11,16 +8,23 @@ use base 'Exporter';
 
 BEGIN {
   our @EXPORT      = qw/compress decompress/;
-  our @EXPORT_OK   = qw( $MAGIC $BITS_MASK $BLOCK_MASK $RESET_CODE );
+  our @EXPORT_OK   = qw(
+    $MAGIC       $MASK_BITS    $MASK_BLOCK
+    $RESET_CODE  $BL_INIT_CODE $NR_INIT_CODE
+    $INIT_CODE_SIZE
+  );
   our %EXPORT_TAGS = (
     const => \@EXPORT_OK,
   );
 }
 
-our $MAGIC      = "\037\235";
-our $BITS_MASK  = 0x1f;
-our $BLOCK_MASK = 0x80;
-our $RESET_CODE = 256;
+our $MAGIC          = "\037\235";
+our $MASK_BITS      = 0x1f;
+our $MASK_BLOCK     = 0x80;
+our $RESET_CODE     = 256;
+our $BL_INIT_CODE   = 257;
+our $NR_INIT_CODE   = 256;
+our $INIT_CODE_SIZE = 9;
 
 use Compress::LZW::Compressor;
 use Compress::LZW::Decompressor;
@@ -41,15 +45,6 @@ sub decompress {
 }  
 
 
-sub _detect_lsb_first {
-  use Config;
-  
-  return 1 if substr($Config{byteorder},0,4) eq '1234';
-  return 0;
-}
-
-
-
 1;
 
 __END__
@@ -64,7 +59,7 @@ Compress::LZW - Pure-Perl implementation of scaling LZW
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -75,11 +70,11 @@ version 0.03
 
 =head1 DESCRIPTION
 
-C<Compress::LZW> is a perl implementation of the Lempel-Ziv-Welch
-compression algorithm, which should no longer be patented worldwide.
-It is shooting for loose compatibility with the flavor of LZW 
-found in the classic UNIX compress(1), though there are a few
-variations out there today.  I test against ncompress on Linux x86.
+C<Compress::LZW> is a perl implementation of the Lempel-Ziv-Welch compression
+algorithm, which should no longer be patented worldwide.  It is shooting for
+loose compatibility with the flavor of LZW found in the classic UNIX
+compress(1), though there are a few variations out there today.  I test against
+ncompress on Linux x86.
 
 =head1 FUNCTIONS
 
@@ -93,20 +88,24 @@ Wraps L<Compress::LZW::Compressor>
 
 Accepts a (compressed) scalar, returns decompressed data in a scalar.
 
-Wraps L<Compress::LZW::Deompressor>
+Wraps L<Compress::LZW::Decompressor>
 
 =head1 EXPORTS
 
-C<compress> C<decompress>
+Default: C<compress> C<decompress>
 
 =head1 SEE ALSO
 
-The implementations, L<Compress::LZW::Compressor> and L<Compress::LZW::Decompressor>.
+The implementations, L<Compress::LZW::Compressor> and
+L<Compress::LZW::Decompressor>.
 
-Other Compress::* modules, especially Compress::LZV1, Compress::LZF and Compress::Zlib.
+Other Compress::* modules, especially Compress::LZV1, Compress::LZF and
+Compress::Zlib.
 
-I definitely studied some other implementations that deserve credit, in particular: Sean O'Rourke, E<lt>SEANOE<gt> - Original author, C<Compress::SelfExtracting>, and another by Rocco Caputo
-which was posted online.
+I definitely studied some other implementations that deserve credit, in
+particular: Sean O'Rourke, E<lt>SEANOE<gt> - Original author,
+C<Compress::SelfExtracting>, and another by Rocco Caputo which was posted
+online.
 
 =head1 AUTHOR
 
@@ -114,7 +113,7 @@ Meredith Howard <mhoward@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Meredith Howard.
+This software is copyright (c) 2015 by Meredith Howard.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
